# Finance tracker python CLI app<br>

### Version 1.4.0.<br>

* added currencies conversion from Foreign Exchange Market.<br>
* added convertor for entered amount.<br>
* added input checks.<br>
* added program name title
* added delete string functionality 
* overhaul, fixes
* packed to pip

### Requirements:
* Python 3.11
* Pip

### Install from pip:
```
pip install FinanceTrackerCLI
```
### Usage:
* Navigate to package folder
* Open terminal \ command line
* For Macos:
```
python3 finance_tracker.py
```
* For Windows:
```
py finance_tracker.py
```
* profit